@@ -3,9 +3,12 @@ module MCollective
   # and the background, keeps detailed stats and provides hooks to access
   # all this information
   class Runner
+    include Translatable
+
     def initialize(configfile)
       @config = Config.instance
       @config.loadconfig(configfile) unless @config.configured
+      @config.mode = :server
 
       @stats = PluginManager["global_stats"]
 
@@ -19,12 +22,13 @@ module MCollective
 
       unless Util.windows?
         Signal.trap("USR1") do
-          Log.info("Reloading all agents after receiving USR1 signal")
+          log_code(:PLMC2, "Reloading all agents after receiving USR1 signal", :info)
           @agents.loadagents
         end
 
         Signal.trap("USR2") do
-          Log.info("Cycling logging level due to USR2 signal")
+          log_code(:PLMC3, "Cycling logging level due to USR2 signal", :info)
+
           Log.cycle_level
         end
       else
@@ -43,7 +47,7 @@ module MCollective
       begin
         PluginManager["registration_plugin"].run(@connection) unless @config.registerinterval == 0
       rescue Exception => e
-        Log.error("Failed to start registration plugin: #{e}")
+        logexception(:PLMC4, "Failed to start registration plugin: %{error}", :error, e)
       end
 
       loop do
@@ -53,22 +57,21 @@ module MCollective
           unless request.agent == "mcollective"
             agentmsg(request)
           else
-            Log.error("Received a control message, possibly via 'mco controller' but this has been deprecated")
+            log_code(:PLMC5, "Received a control message, possibly via 'mco controller' but this has been deprecated", :error)
           end
         rescue SignalException => e
-          Log.warn("Exiting after signal: #{e}")
+          logexception(:PLMC7, "Exiting after signal: %{error}", :warn, e)
           @connection.disconnect
           raise
 
         rescue MsgTTLExpired => e
-          Log.warn(e)
+          logexception(:PLMC9, "Expired Message: %{error}", :warn, e)
 
         rescue NotTargettedAtUs => e
-          Log.debug("Message does not pass filters, ignoring")
+          log_code(:PLMC6, "Message does not pass filters, ignoring", :debug)
 
         rescue Exception => e
-          Log.warn("Failed to handle message: #{e} - #{e.class}\n")
-          Log.warn(e.backtrace.join("\n\t"))
+          logexception(:PLMC10, "Failed to handle message: %{error}", :warn, e, true)
         end
       end
     end
@@ -76,7 +79,7 @@ module MCollective
     private
     # Deals with messages directed to agents
     def agentmsg(request)
-      Log.debug("Handling message for agent '#{request.agent}' on collective '#{request.collective}'")
+      log_code(:PLMC8, "Handling message for agent '%{agent}' on collective '%{collective} with requestid '%{requestid}'", :debug, :agent => request.agent, :collective => request.collective, :requestid => request.requestid)
 
       @agents.dispatch(request, @connection) do |reply_message|
         reply(reply_message, request) if reply_message
